
:autogenerated:

weylchamber.local_invariants module
===================================

.. currentmodule:: weylchamber.local_invariants

.. automodule:: weylchamber.local_invariants
    :members: DEFAULT_WEYL_PRECISSION, J_T_LI, closest_LI, cos, g1g2g3, g1g2g3_from_c1c2c3, make_LI_krotov_chi_constructor, pi, sin
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Functions:

    .. autosummary::
        :nosignatures:

        J_T_LI
        closest_LI
        g1g2g3
        g1g2g3_from_c1c2c3
        make_LI_krotov_chi_constructor





    ``__all__``: :func:`J_T_LI <weylchamber.local_invariants.J_T_LI>`, :func:`closest_LI <weylchamber.local_invariants.closest_LI>`, :func:`g1g2g3 <weylchamber.local_invariants.g1g2g3>`, :func:`g1g2g3_from_c1c2c3 <weylchamber.local_invariants.g1g2g3_from_c1c2c3>`, :func:`make_LI_krotov_chi_constructor <weylchamber.local_invariants.make_LI_krotov_chi_constructor>`



    Reference
    ---------